@@ -152,6 +152,8 @@ class FilterBase(object):
     init_attrs_for_instance = ()
     # current HTML renderer allows for "input", "input2", and/or "select"
     input_types = 'input',
+    # match operators to the HTML5 type(s)
+    html_input_types = {}
     # does this filter take a list of values in it's set() method
     receives_list = False
     # does this filter apply to the HAVING clause
@@ -310,10 +312,13 @@ class FilterBase(object):
         return None
 
     def serialize_filter_operator(self, op):
+        field_type = op.field_type
+        if op in self.html_input_types:
+            field_type += '.' + self.html_input_types[op]
         return types.FilterOperator(
             key=op.key,
             label=op.display,
-            field_type=op.field_type,
+            field_type=field_type,
             hint=op.hint,
         )
 
@@ -631,6 +636,42 @@ class OptionsEnumFilter(OptionsFilterBase):
         return self.value_modifier.to_python(value)
 
 
+class OptionsEnumArrayFilter(OptionsEnumFilter):
+    """Handle filtering array fields having an enum type.
+
+    Uses SA's any/contains operators, while correcting for enum type discrepancy.
+
+    Note, this is known to work with Postgres, but has not been tested on other platforms."""
+
+    def get_search_expr(self):
+        """Match up a search value to option display, grab the corresponding keys, and search."""
+        # The important thing to remember here is that a user will be searching for the displayed
+        # value, not the key that generated it. We need to do some prep work to search options
+        # to get the keys needed for lookup into the data source.
+        def search(value):
+            matching_keys = self.match_keys_for_value(value)
+            return self.sa_col.contains(matching_keys)
+        return search
+
+    def apply(self, query):
+        """Query modifier to apply the needed clauses for filter inputs."""
+        if self.op == self.ops.is_:
+            if len(self.value1) == 1 and self.value1[0]:
+                return query.filter(self.sa_col.any(self.value1[0].name))
+            elif len(self.value1) > 1:
+                return query.filter(self.sa_col.contains(self.value1))
+            else:
+                return query
+        if self.op == self.ops.not_is:
+            if len(self.value1) == 1 and self.value1[0]:
+                return query.filter(~self.sa_col.any(self.value1[0].name))
+            elif len(self.value1) > 1:
+                return query.filter(~self.sa_col.contains(self.value1))
+            else:
+                return query
+        return super().apply(query)
+
+
 class TextFilter(FilterBase):
     """Filter with single freeform text input."""
     operators = (ops.eq, ops.not_eq, ops.contains, ops.not_contains, ops.empty, ops.not_empty)
@@ -985,17 +1026,6 @@ class _DateMixin(object):
             return base_expr
         return expr
 
-    def serialize_filter_operator(self, op):
-        field_type = op.field_type
-        if op in self.html_input_types:
-            field_type += '.' + self.html_input_types[op]
-        return types.FilterOperator(
-            key=op.key,
-            label=op.display,
-            field_type=field_type,
-            hint=op.hint,
-        )
-
     def serialize_filter_spec(self):
         base_spec = super().serialize_filter_spec()
         return types.OptionsFilterSpec(
